@@ -11,7 +11,6 @@
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from typing import Optional
 
 from holidays.calendars.chinese import _ChineseLunisolar, CHINESE_CALENDAR
 from holidays.calendars.gregorian import APR
@@ -23,7 +22,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
     Chinese lunisolar calendar holidays.
     """
 
-    def __init__(self, cls=None, show_estimated=False, calendar=CHINESE_CALENDAR) -> None:
+    def __init__(self, cls=None, *, show_estimated=False, calendar=CHINESE_CALENDAR) -> None:
         self._chinese_calendar = (
             cls(calendar=calendar) if cls else _ChineseLunisolar(calendar=calendar)
         )
@@ -83,8 +82,8 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         return self._chinese_calendar.winter_solstice_date(self._year)[0]
 
     def _add_chinese_calendar_holiday(
-        self, name: str, dt_estimated: tuple[Optional[date], bool], days_delta: int = 0
-    ) -> Optional[date]:
+        self, name: str, dt_estimated: tuple[date | None, bool], days_delta: int = 0
+    ) -> date | None:
         """
         Add Chinese calendar holiday.
 
@@ -92,10 +91,13 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         is an estimation.
         """
         return self._add_eastern_calendar_holiday(
-            name, dt_estimated, self._chinese_calendar_show_estimated, days_delta
+            name,
+            dt_estimated,
+            show_estimated=self._chinese_calendar_show_estimated,
+            days_delta=days_delta,
         )
 
-    def _add_chinese_birthday_of_buddha(self, name) -> Optional[date]:
+    def _add_chinese_birthday_of_buddha(self, name) -> date | None:
         """
         Add Birthday of the Buddha by Chinese lunar calendar (8th day of the
         4th lunar month).
@@ -109,7 +111,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.buddha_birthday_date(self._year)
         )
 
-    def _add_chinese_day_before_new_years_eve(self, name) -> Optional[date]:
+    def _add_chinese_day_before_new_years_eve(self, name) -> date | None:
         """
         Add day before Chinese New Year's Eve (second to last day of 12th lunar month).
 
@@ -120,7 +122,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=-2
         )
 
-    def _add_chinese_new_years_eve(self, name) -> Optional[date]:
+    def _add_chinese_new_years_eve(self, name) -> date | None:
         """
         Add Chinese New Year's Eve (last day of 12th lunar month).
 
@@ -131,7 +133,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=-1
         )
 
-    def _add_chinese_new_years_day(self, name) -> Optional[date]:
+    def _add_chinese_new_years_day(self, name) -> date | None:
         """
         Add Chinese New Year's Day (first day of the first lunar month).
 
@@ -143,7 +145,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year)
         )
 
-    def _add_chinese_new_years_day_two(self, name) -> Optional[date]:
+    def _add_chinese_new_years_day_two(self, name) -> date | None:
         """
         Add Chinese New Year's Day Two.
 
@@ -153,7 +155,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+1
         )
 
-    def _add_chinese_new_years_day_three(self, name) -> Optional[date]:
+    def _add_chinese_new_years_day_three(self, name) -> date | None:
         """
         Add Chinese New Year's Day Three.
 
@@ -163,7 +165,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+2
         )
 
-    def _add_chinese_new_years_day_four(self, name) -> Optional[date]:
+    def _add_chinese_new_years_day_four(self, name) -> date | None:
         """
         Add Chinese New Year's Day Four.
 
@@ -173,7 +175,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+3
         )
 
-    def _add_chinese_new_years_day_five(self, name) -> Optional[date]:
+    def _add_chinese_new_years_day_five(self, name) -> date | None:
         """
         Add Chinese New Year's Day Five.
 
@@ -183,7 +185,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+4
         )
 
-    def _add_daeboreum_day(self, name) -> Optional[date]:
+    def _add_daeboreum_day(self, name) -> date | None:
         """
         Add Daeboreum Day (15th day of 1st lunar month).
 
@@ -195,7 +197,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.lunar_new_year_date(self._year), days_delta=+14
         )
 
-    def _add_dongzhi_festival(self, name) -> Optional[date]:
+    def _add_dongzhi_festival(self, name) -> date | None:
         """
         Add Dongzhi Festival (Chinese Winter Solstice).
 
@@ -206,7 +208,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         """
         return self._add_holiday(name, self._dongzhi_festival)
 
-    def _add_hanshi_festival(self, name) -> Optional[date]:
+    def _add_hanshi_festival(self, name) -> date | None:
         """
         Add Hanshi Festival (105 days after Winter Solstice).
 
@@ -229,7 +231,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
         """
         return self._add_holiday(name, self._qingming_festival)
 
-    def _add_double_ninth_festival(self, name) -> Optional[date]:
+    def _add_double_ninth_festival(self, name) -> date | None:
         """
         Add Double Ninth Festival (9th day of 9th lunar month).
 
@@ -241,7 +243,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.double_ninth_date(self._year)
         )
 
-    def _add_dragon_boat_festival(self, name) -> Optional[date]:
+    def _add_dragon_boat_festival(self, name) -> date | None:
         """
         Add Dragon Boat Festival (5th day of 5th lunar month).
 
@@ -253,7 +255,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.dragon_boat_date(self._year)
         )
 
-    def _add_hung_kings_day(self, name) -> Optional[date]:
+    def _add_hung_kings_day(self, name) -> date | None:
         """
         Add Hùng Kings' Temple Festival (10th day of the 3rd lunar month).
 
@@ -265,7 +267,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.hung_kings_date(self._year)
         )
 
-    def _add_mid_autumn_festival(self, name) -> Optional[date]:
+    def _add_mid_autumn_festival(self, name) -> date | None:
         """
         Add Mid Autumn Festival (15th day of the 8th lunar month).
 
@@ -277,7 +279,7 @@ class ChineseCalendarHolidays(EasternCalendarHolidays):
             name, self._chinese_calendar.mid_autumn_date(self._year)
         )
 
-    def _add_mid_autumn_festival_day_two(self, name) -> Optional[date]:
+    def _add_mid_autumn_festival_day_two(self, name) -> date | None:
         """
         Add Mid Autumn Festival Day Two (16th day of the 8th lunar month).
 
